@@ -72,7 +72,9 @@ step_corr <- function(recipe,
                       use = "pairwise.complete.obs",
                       method = "pearson",
                       removals = NULL,
-                      skip = FALSE) {
+                      skip = FALSE,
+                      id = rand_id("corr")
+                      ) {
   add_step(
     recipe,
     step_corr_new(
@@ -83,22 +85,14 @@ step_corr <- function(recipe,
       use = use,
       method = method,
       removals = removals,
-      skip = skip
+      skip = skip,
+      id = id
     )
   )
 }
 
 step_corr_new <-
-  function(
-    terms = NULL,
-    role = NA,
-    trained = FALSE,
-    threshold = NULL,
-    use = NULL,
-    method = NULL,
-    removals = NULL,
-    skip = FALSE
-  ) {
+  function(terms, role, trained, threshold, use, method, removals, skip, id) {
     step(
       subclass = "corr",
       terms = terms,
@@ -108,13 +102,16 @@ step_corr_new <-
       use = use,
       method = method,
       removals = removals,
-      skip = skip
+      skip = skip,
+      id = id
     )
   }
 
 #' @export
 prep.step_corr <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
+  check_type(training[, col_names])
+
   filter <- corr_filter(
     x = training[, col_names],
     cutoff = x$threshold,
@@ -130,15 +127,16 @@ prep.step_corr <- function(x, training, info = NULL, ...) {
     use = x$use,
     method = x$method,
     removals = filter,
-    skip = x$skip
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @export
-bake.step_corr <- function(object, newdata, ...) {
+bake.step_corr <- function(object, new_data, ...) {
   if (length(object$removals) > 0)
-    newdata <- newdata[,!(colnames(newdata) %in% object$removals)]
-  as_tibble(newdata)
+    new_data <- new_data[,!(colnames(new_data) %in% object$removals)]
+  as_tibble(new_data)
 }
 
 print.step_corr <-
@@ -198,9 +196,11 @@ tidy_filter <- function(x, ...) {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = na_chr)
   }
+  res$id <- x$id
   res
 }
 
 #' @rdname step_corr
 #' @param x A `step_corr` object.
+#' @export
 tidy.step_corr <- tidy_filter
