@@ -12,9 +12,9 @@
 #' @param role Not used by this step since no new variables are
 #'  created.
 #' @param min A single numeric value for the smallest value in the
-#'  range
+#'  range.
 #' @param max A single numeric value for the largest value in the
-#'  range
+#'  range.
 #' @param ranges A character vector of variables that will be
 #'  normalized. Note that this is ignored until the values are
 #'  determined by [prep.recipe()]. Setting this value will
@@ -59,7 +59,8 @@ step_range <-
            min = 0,
            max = 1,
            ranges = NULL,
-           skip = FALSE) {
+           skip = FALSE,
+           id = rand_id("range")) {
     add_step(
       recipe,
       step_range_new(
@@ -69,19 +70,14 @@ step_range <-
         min = min,
         max = max,
         ranges = ranges,
-        skip = skip
+        skip = skip,
+        id = id
       )
     )
   }
 
 step_range_new <-
-  function(terms = NULL,
-           role = NA,
-           trained = FALSE,
-           min = 0,
-           max = 1,
-           ranges = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, min, max, ranges, skip, id) {
     step(
       subclass = "range",
       terms = terms,
@@ -90,7 +86,8 @@ step_range_new <-
       min = min,
       max = max,
       ranges = ranges,
-      skip = skip
+      skip = skip,
+      id = id
     )
   }
 
@@ -98,6 +95,8 @@ step_range_new <-
 #' @export
 prep.step_range <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
+  check_type(training[, col_names])
+
   mins <-
     vapply(training[, col_names], min, c(min = 0), na.rm = TRUE)
   maxs <-
@@ -109,13 +108,14 @@ prep.step_range <- function(x, training, info = NULL, ...) {
     min = x$min,
     max = x$max,
     ranges = rbind(mins, maxs),
-    skip = x$skip
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @export
-bake.step_range <- function(object, newdata, ...) {
-  tmp <- as.matrix(newdata[, colnames(object$ranges)])
+bake.step_range <- function(object, new_data, ...) {
+  tmp <- as.matrix(new_data[, colnames(object$ranges)])
   tmp <- sweep(tmp, 2, object$ranges[1, ], "-")
   tmp <- tmp * (object$max - object$min)
   tmp <- sweep(tmp, 2, object$ranges[2, ] - object$ranges[1, ], "/")
@@ -126,19 +126,20 @@ bake.step_range <- function(object, newdata, ...) {
 
   if (is.matrix(tmp) && ncol(tmp) == 1)
     tmp <- tmp[, 1]
-  newdata[, colnames(object$ranges)] <- tmp
-  as_tibble(newdata)
+  new_data[, colnames(object$ranges)] <- tmp
+  as_tibble(new_data)
 }
 
 print.step_range <-
   function(x, width = max(20, options()$width - 30), ...) {
     cat("Range scaling to [", x$min, ",", x$max, "] for ", sep = "")
-    printer(names(x$ranges), x$terms, x$trained, width = width)
+    printer(colnames(x$ranges), x$terms, x$trained, width = width)
     invisible(x)
   }
 
 #' @rdname step_range
 #' @param x A `step_range` object.
+#' @export
 tidy.step_range <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = colnames(x$ranges),
@@ -150,5 +151,6 @@ tidy.step_range <- function(x, ...) {
                   min = na_dbl,
                   max = na_dbl)
   }
+  res$id <- x$id
   res
 }
